TextRepresentation
==================

.. currentmodule:: pykeen.nn.representation

.. autoclass:: TextRepresentation
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~TextRepresentation.from_dataset
      ~TextRepresentation.from_triples_factory

   .. rubric:: Methods Documentation

   .. automethod:: from_dataset
   .. automethod:: from_triples_factory
